# Python Game Data Generator

The goal of this project is to provide a game event generator to show case AWS Analytics and Machine Learning services.

# TUX

The project will use the racing game TUX. TUX is a session based game. 
You are driving a cars and compete with 4 other players during a race.
The winner of a race earn 10 points, the second 5, the third 2 and the last 0 point.
The average time of a race is 3 minutes.
Players are ranked into a leaderboard they can view in the game and on the web.
Players can invite friends in the game.
Player can chat with the players in the race but also in the lobby.
Player can purchase in game currency to buy items in a shop to customize their car and strike opponents in a race.
There are 3 gae currenc pack:
- 5$
- 20$
- 100$

# We want to measure the following metrics

- Daily Active Users (DAU)
- Monthly Active Users (MAU)
- Daily game connection number
- Average game connection duration
- Daily game session number
- Retention D1/D2/D3/D4/D5/6/D7/D14/D28
- Average game session duration
- ARPU (Average Revenue Per User)
- ARPDAU (Average Revenue Per Daily User)
- ARPPU (Average Revenue Per Paying User)

# We want to track the following player state

- Level
- Win/Lost session
- # of friend asks
- # of friends
- # of chat message
- # of leader boards views
- # of items bought
- Spend in €
- life time value

# Events

- 
- 
- 
- 
- 

# Churn Prediction Features V1

- # of connections
- # of connections / days
- # of connections / weeks
- # of connections / months
- # of sessions
- # of sessions / days
- # of sessions / weeks
- # of sessions / months
- # of friends
- # of friends / days
- # of friends / weeks
- # of chat messages
- # of chat messages / days
- # of chat messages / weeks
- # of items boughts
- # of items boughts / days
- # of items boughts / weeks